==> kube-integration-1.3.13.tgz: package/lib/kube.manager.js <==
'use strict';

const _                   = require('lodash');
const ResourceBaseManager = require('./kube-native/resource.base.controller');
const controllers         = require('./kube.controllers')();
const config              = require('./../config');
const EventEmitter        = require('eventemitter2').EventEmitter2;
const r                   = require('request-promise');
const kubeConfigBuilder = require('kube-config-builder');

class KubeManager extends EventEmitter {


    static constructNewManagerPromise(credentials, requestOptiton = {}){
        return kubeConfigBuilder.Builder.ConstructKubeAPIConfigJson(credentials)
            .then(config => new KubeManager(config, requestOptiton));
    }

    constructor(clusterConfig, requestOptiton = {}) {
        super();
        this._clusterConfig = clusterConfig;
        this._requestOptiton = requestOptiton;
        this.buildControllers();
    }

    buildControllers() {
        controllers.map((controller) => {
            // create function like getDeplymentController for all controllers in /kube.controllers
            const name = _.camelCase(`get ${controller.name} controller`);
            this[name] = (ns) => {
                const opt = {
                    kubeClient: this._initManager(controller.Type, ns),
                    kubeManager: this,
                    selector: this._clusterConfig.name,
                    events: controller.events,
                    baseKubePath: controller.baseKubePath,
                    Entity: controller.Entity,
                    builders: controller.builders,
                    StatusAnalyzerClass: controller.StatusAnalyzer,
                    ns
                };

                let ctrl;
                if (controller.Controller) {
                    ctrl = new controller.Controller(opt);
                } else {
                    ctrl = new ResourceBaseManager(opt);
                }
                ctrl.onAny((event, data) => {
                    this.emit(event, _.merge(data, {
                        controller: controller.name
                    }));
                });
                return ctrl;
            };
        });
    }

    getName() {
        return _.get(this, '_clusterConfig.name');
    }

    _initManager(type, ns) {
        return new type(_.merge(this._clusterConfig, ns ? { namespace: ns } : {}, {
            request: {
                headers: {
                    'User-Agent': config.userAgent
                },
                timeout: parseInt(_.get(this, '_requestOptiton.timeout', '120000'))
            }
        }));
    }

    verifyCredentials() {
        return this.getNamespaceController().get();
    }
}

module.exports = KubeManager;

==> kube-integration-1.4.1.tgz: package/lib/kube.manager.js <==
'use strict';

const _                   = require('lodash');
const ResourceBaseManager = require('./kube-native/resource.base.controller');
const controllers         = require('./kube.controllers')();
const config              = require('./../config');
const EventEmitter        = require('eventemitter2').EventEmitter2;
const r                   = require('request-promise');
const kubeConfigBuilder = require('kube-config-builder');

class KubeManager extends EventEmitter {


    static constructNewManagerPromise(credentials, requestOptiton = {}){
        return kubeConfigBuilder.Builder.ConstructKubeAPIConfigJson(credentials)
            .then(config => new KubeManager(config, requestOptiton));
    }

    constructor(clusterConfig, requestOptiton = {}) {
        super();
        this._clusterConfig = clusterConfig;
        this._requestOptiton = requestOptiton;
        this.buildControllers();
    }

    buildControllers() {
        controllers.map((controller) => {
            // create function like getDeplymentController for all controllers in /kube.controllers
            const name = _.camelCase(`get ${controller.name} controller`);
            this[name] = (ns) => {
                const opt = {
                    kubeClient: this._initManager(controller.Type, ns),
                    kubeManager: this,
                    selector: this._clusterConfig.name,
                    events: controller.events,
                    baseKubePath: controller.baseKubePath,
                    Entity: controller.Entity,
                    builders: controller.builders,
                    StatusAnalyzerClass: controller.StatusAnalyzer,
                    ns
                };

                let ctrl;
                if (controller.Controller) {
                    ctrl = new controller.Controller(opt);
                } else {
                    ctrl = new ResourceBaseManager(opt);
                }
                ctrl.onAny((event, data) => {
                    this.emit(event, _.merge(data, {
                        controller: controller.name
                    }));
                });
                return ctrl;
            };
        });
    }

    getName() {
        return _.get(this, '_clusterConfig.name');
    }

    _initManager(type, ns) {
        const timeout = parseInt(_.get(this, '_requestOptiton.timeout', '120000'));
        const request = {
            headers: {
                'User-Agent': config.userAgent
            },
            timeout,
        };
        const cnf = _.merge(this._clusterConfig, ns ? { namespace: ns } : {}, {
            request: {
                request,
            },
        });
        return new type(cnf);
    }

    verifyCredentials() {
        return this.getNamespaceController().get();
    }
}

module.exports = KubeManager;
